@@ -52,6 +52,11 @@ typedef enum fmReturn_enum
     FM_ST_NOT_READY                      = -22, //!< Fabric Manager is not ready to serve GFM API requests.
     FM_ST_RESOURCE_USED_IN_THIS_PARTITION = -23, //!< Resource is already in use in this partition
     FM_ST_RESOURCE_USED_IN_ANOTHER_PARTITION = -24, //!< Resource is already in use in another partition
+    FM_ST_PARTITION_MISWIRED_TRUNKS      = -25, //!< Partition has miswired trunks
+    FM_ST_PARTITION_INSUFFICIENT_TRUNKS  = -26, //!< Partition has insufficient trunks
+    FM_ST_PARTITION_MISSING_SWITCHES     = -27, //!< Partition has missing switches
+    FM_ST_PARTITION_NETWORK_CONFIG_ERROR = -28, //!< Partition has network configuration error
+    FM_ST_PARTITION_ROUTE_PROGRAMMING_ERROR = -29, //!< Partition has route programming error
 } fmReturn_t;
 
 typedef void *fmHandle_t;   //!< Identifier for Fabric Manager API interface Handle
@@ -81,6 +86,11 @@ typedef void *fmHandle_t;   //!< Identifier for Fabric Manager API interface Han
  */
 #define FM_CMD_PORT_NUMBER 6666
 
+/**
+ * Buffer size guaranteed to be large enough to hold transaction id
+ */
+#define FM_TRANSACTION_ID_BUFFER_SIZE 40
+
 /**
  * Connection options for fmConnect()
  */
@@ -95,9 +105,34 @@ typedef struct
 } fmConnectParams_v1;
 
 /**
- * Typedef for \ref fmConnectParams_v1
+ * @enum nvFmApiAddrTypes
+ * @brief an enumeration of supported address types
  */
-typedef fmConnectParams_v1 fmConnectParams_t;
+enum nvFmApiAddrTypes
+{
+    NV_FM_API_ADDR_TYPE_UNKNOWN = 0,
+    NV_FM_API_ADDR_TYPE_INET = 1,
+    NV_FM_API_ADDR_TYPE_UNIX = 2,
+    NV_FM_API_ADDR_TYPE_VSOCK = 3,
+};
+
+typedef struct 
+{
+    unsigned int version;                   //!< Version number. Use fmConnectParams_version
+    char addressInfo[FM_MAX_STR_LENGTH];    /*!< identifier information interpreted based on addressType's value; 
+                                                 when addressType == NV_FM_API_ADDR_TYPE_INET addressInfo is `<ipv4>:<port_number>`;
+                                                 when addressType == NV_FM_API_ADDR_TYPE_UNIX addressInfo is `<unix_path>`;
+                                                 when addressType == NV_FM_API_ADDR_TYPE_VSOCK addressInfo is `<cid>:<port_number>` */
+    unsigned int timeoutMs;                 /*!< When attempting to connect to the running FM instance, 
+                                              how long should we wait in milliseconds before giving up */
+    unsigned int addressIsUnixSocket;       /*!< deprecated; use addressType instead */
+    enum nvFmApiAddrTypes addressType;           /*!< The type of address in addressInfo */
+} fmConnectParams_v2;
+
+/**
+ * Typedef for \ref fmConnectParams_t
+ */
+typedef fmConnectParams_v2 fmConnectParams_t;
  
 /**
 * Version 1 for \ref fmConnectParams_v1
@@ -105,9 +140,14 @@ typedef fmConnectParams_v1 fmConnectParams_t;
 #define fmConnectV1Params_version1 MAKE_FM_PARAM_VERSION(fmConnectParams_v1, 1)
 
 /**
-* Latest version for \ref fmConnectParams_v1
+* Version 2 for \ref fmConnectParams_v2
 */
-#define fmConnectParams_version fmConnectV1Params_version1
+#define fmConnectV2Params_version2 MAKE_FM_PARAM_VERSION(fmConnectParams_v2, 2)
+
+/**
+* Latest version for \ref fmConnectParams_t
+*/
+#define fmConnectParams_version fmConnectV2Params_version2
 
 /**
  * Max number of GPUs supported by FM
